#
# spec file for package maildir-utils
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maildir-utils
Version:        1.6.10
Release:        bp155.2.47
Summary:        Maildir indexer and searcher
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            https://www.djcbsoftware.nl/code/mu/
Source:         https://github.com/djcb/mu/releases/download/%{version}/mu-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake >= 1.14
BuildRequires:  emacs-nox >= 24.4
# Optional: for outputting of messages in json
BuildRequires:  json-glib-devel
BuildRequires:  libtool
BuildRequires:  libxapian-devel
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gmime-3.0) >= 3.0

%description
Set of utilities to index and search Maildirs. Upstream name is mu.

%package -n mu4e
Summary:        Emacs-based e-mail client based on the mu e-mail indexer/searcher
Group:          Productivity/Networking/Email/Clients
Requires:       %{name} = %{version}
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description -n mu4e
mu4e is an emacs-based e-mail client. It is based on the mu e-mail indexer/searcher.

%prep
%setup -q -n mu-%{version}

%build
autoreconf -i
%configure

#bsc#1111950: build individually for now. to have reproducible.
%make_build -C lib
%make_build

%install
%make_install

%post -n mu4e
%install_info --info-dir=%{_infodir} %{_infodir}/mu4e.info.gz

%preun -n mu4e
%install_info_delete --info-dir=%{_infodir} %{_infodir}/mu4e.info.gz

%files
%doc ChangeLog README.org
%license COPYING
%dir %{_datadir}/doc/mu
%{_bindir}/mu
%{_datadir}/doc/mu/NEWS.org
%{_mandir}/man?/*%{ext_man}

%files -n mu4e
%{_datadir}/doc/mu/mu4e-about.org
%dir %{_datadir}/emacs/site-lisp/mu4e/
%{_datadir}/emacs/site-lisp/mu4e/*.{el,elc}
%{_infodir}/mu4e.info%{?ext_info}

%changelog
* Fri Dec  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.10:
  * fix --terminate help display
  * make undo work across compose saves
  * ignore .update when store is empty
  * add xapian deps
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.9:
  * Just a version bump because 1.6.8 had a mistake in them
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.8:
  * mu-query: honor maxnum for threaded queries
  * lib/mu: fix a few leaks
  * guile: fix user script path detection
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.7:
  * Add Emacs v29 support for enabling mu4e
  * mu-find: unbreak json output
  * build: detect wordexp
  * mu4e.texi: improve regexp example
  * mu int: improve docs for regexp addresses
  * mu4e.texi: Add regexp --my-address example
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.6:
  * Fix mu-init manpage markup
  * Extracting attachments #2116
  * mu4e-view: remove overlays before erasing
  * mu4e-view: remove overlays when erasing
  * mu4e-server: rename from mu4e-proc
  * mu4e-utils: refactor into mu4e-helpers, separate files
  * mu4e-view: remove old view
  * vars: refactor variables
  * mu4e-search: split off search functionality in minor-mode
  * build: update coding-style settings
  * mu4e-context: make it a minor-mode
  * mu4e-context: fix some flycheck warnings
  * mu4e-helpers: split off from mu4e-utils
  * build: make meson the default build system
  * build: require c++17
* Fri Aug 27 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.5:
  * Create numbered backup of attached file when already exists (#2090)
  * Use and instead of progn and fix some long lines
  * Fix mu4e-view-save-attachments void variable
  * mu4e-headers: restore mark after update
  * view-gnus: Add S-SPC to scroll-down binding
* Mon Aug 23 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.4:
  * mu4e: Add back the `h' keybinding to toggle HTML view in a gnus article
  * mu4e: toggle-html: use if-let/seq-find
  * mu4e-view-gnus: Fix some flycheck warnings (doc)
  * Create numbered backup of attached file when already exists #2090
  * Use and instead of progn and fix some long lines
  * mu4e-compose: regenerate Date: when user removes it
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.3:
  * A few more updates -- lazy indexing and thread-subjects, org
    link config.
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.2:
  * Some more fixes for problems found in the 1.6 series.
* Sun Aug  1 2021 Miquel Sabate Sola <msabate@suse.com>
- Update to 1.6.1:
  * Fixes for some problems found by early adopters.
  NOTE: After upgrading, you need to call mu init, with your preferred
  parameters before you can use mu/mu4e. This is because the underlying
  database-schema has changed.
* Mon Jan 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.15:
  * Fix 'mu4e-interrupt-update-mail alias definition
  * mu-msg-sexp: Improve list-post regexp
* Mon Jan  4 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.14:
  * lib: fix mu-msg-json build
  * mu4e-view: Use 'mu4e not "mu4e" when extracting
  * Fix `mu help` doesn't show the `init` command
  * mu4e: avoid calendar charset error
  * Disable `mm-verify-option` let-bounded in `mu4e~view-gnus`
* Mon Aug 10 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.13:
  * Bugfix release, no changes provided
* Mon Jul 27 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.12:
  * Bugfix release, no changes provided
* Wed Jun 10 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.10:
  * mu4e-headers: require mule-util for truncate-string-ellipsis
* Mon Jun  8 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.9:
  * mu4e: avoid trouble with truncate-string-to-width
* Mon Jun  1 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.8:
  * Strip properties from mu4e-completing-read-function results
  * mu4e: remove easy-accounts / no-trash-providers for now
  * Add missing space between signature verification and signers
  * mu4e-maildir-shortcuts: update for today's functionality
  * mu4e-maildir-shortcuts: update for today's functionality
* Sun May 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.6:
  * mu: always sort descending within threads
  * mu-server: disable readline support for now
  * Fix make-mu4e-context-account
  * mu4e-compose: fix external use (`compose-mail')
  * mu4e: support 'no trash flag' for all mark-for-trash
* Mon May 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.5:
  * typo in mu-query manpage
  * mu4e: use :hide-unread in doc
  * mu4e: better error when mu4e-mu-binary is not set
  * mu: support --eval for server testing
  * mu: don't verify signatures when it's not needed
  * mu4e-bookmarks: improve documentation
  * Make mu4e~view-message available to mu4e-view-mode-hook
  * mu4e: change spacing in main view for info section
  * mu4e.texi: Add note about s/mime
* Mon May  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.4:
  * mu: do a full index when the database is empty
  * mu4e-proc: only rename when maildir is set
  * mu-store: enlarge buffer for strftime
  * mu4e: centralize mode-line context setting code
  * mu4e: update documentation
  * mu4e: start mu4e in compose-handler, when necessary
* Wed Apr 29 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.3:
  * mu4e-view: fix gnus-button click for emacs 26
  * mu4e: Don't use (mu4e-root-maildir) with easy-accounts
  * fix `mu4e-main-buffer-hide-personal-addresses'
  * mu4e-proc: ensure some booleans are nil
  * mu4e: ask for context in mu4e~start
* Mon Apr 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * ~/.mu -> ~/.cache/mu
  * remove mentions of --rebuild
  * properly close config group
* Sun Apr 19 2020 Alexander Graul <agraul@suse.com>
-Update to 1.4:
  mu:
  * Defaults to XDG Base Directory Specification
  * New subcommand `mu init` to initialize database -- takes
    `--my-address` and `--maildir` parameters, `mu index` does not
    accept them anymore
  * New subcommand `mu info` to display information about the database
  * Contacts are now saved in the database instead of in a separate
    file
  * `--xbatchsize` and `--autoupgrade` (for `mu index`) are removed,
    both are implicit now
  mu4e:
  * Does not use `mu4e-maildir` and `mu4e-user-mail-address-list`
    variables anymore, uses information from `mu init`
  * Performance improvements related to contacts handling
  * Added gnus' calendar-invitation handling
  * Added support for custom headers
  * Added experimental "Account Setup Handler"
  * Org-mode support is enabled by default
  * Speedbar support is disabled by default
  * Messaged-id are added to draft messages (can be found with
    `mu4e-headers-skip-duplicates` enabled)
  * Bookmarks are simple plists now (`make-mu4e-bookmark` was updated)
  * Specific bookmarks can be hidden from main menu
  * `mu4e-maildir-shortcuts` are simple plists now (old format is still
    recognized)
  * Replying to mailing lists has been improved
  * Shows unread/all counts for bookmarks in main menu (on by default)
  * `mu4e-attachment-dir` is also used for composing messages
  * `mu4e` <-> `mu` communication uses s-expressions now (includes a
    REPL for testing)
* Mon Apr  8 2019 mvetter@suse.com
- Update to 1.2:
  mu:
  * Substantial (algorithmic) speed-up of message-threading
  * The query-parser now generates better queries for wildcard
    searches, by using the Xapian machinery for that (when available)
    rather than tranforming into regexp queries
  * The perl backend is hardly used and will be removed; for now we
    just disable it in the build
  * Allow outputing messages in json format, closely following the sexp
    output. This adds an (optional) dependency on the Json-Glib library
  mu4e:
  * Bump the minimal required emacs version to 24.4. This was already
    de-facto true, now it is enforced
  * In mu4e-bookmarks, allow the `:query` element to take a function
    (or lambda) to dynamically generate the query string.
  * There is a new message-view for mu4e, based on the Gnus' article-view.
    This bring a lot of (but not all) of the very rich Gnus article-mode
    feature-set to mu4e, such as S/MIME-support, syntax-highlighting.
    Enable it with: (setq mu4e-view-use-gnus t)
  * Bug fixes
* Tue Mar  5 2019 mvetter@suse.com
- bsc#1111950: Build lib in paralell the rest on one core
* Mon Feb  5 2018 mvetter@suse.com
- Update to 1.0:
  mu:
  * New, custom query parser which replaces Xapian's 'QueryParser'
    both in mu and mu4e. Existing queries should still work, but the
    new engine handles non-alphanumeric queries much better.
  * Support regular expressions in queries
  * cfind: ensure nicks are unique
  * auxiliary programs invoked from mu/mu4e survive terminating the
    shell / emacs
  mu4e:
  * Allow for rewriting message bodies
  * Toggle-menus for header settings
  * electric-quote-(local-)mode work when composing emails
  * Respect format=flowed and delsp=yes for viewing plain-text
    messages
  * Added new mu4e-split-view mode: single-window
  * Add menu item for `untrash'.p
  * Unbreak abbrevs in mu4e-compose-mode
  * Allow forwarding messages as attachments
    (`mu4e-compose-forward-as-attachment')
  * Default to 'skip duplicates' and 'include headers' in
    headers-view, which should be good defaults for most users. Can
    be customized using `mu4e-headers-skip-duplicates' and
    `mu4e-headers-include-related', respectively.
  * Many bug fixed (see github for all the details).
  * Updated documentation
- Remove upstreamed mu4e-1.0-alpha3-gh1168.patch
* Tue Jan 23 2018 dmacvicar@suse.de
- Add patch mu4e-1.0-alpha3-gh1168.patch
  * Fix for https://github.com/djcb/mu/issues/1168
- Make automake version requirement (1.14) explicit
* Mon Dec 18 2017 mvetter@suse.com
- Update to 1.0-alpha3:
  * parser: promote single value to a range for range-fields
  * mu: support 'raw' query (internally)
  * mu: handle funny msgids
  * mu4e: improve msgid quoting
  * mu4e: fix typo in mu4e~docid-msgid-param
* Mon Nov 13 2017 mvetter@suse.com
- Update to 1.0-alpha2:
  * Ensure mu4e-view-mode-hook run after text insertion
  * mu4e: fix bug preventing mu4e-headers-change-sorting to sort by list
  * mu4e: add mu4e-query-rewrite-functio
  * proc: ensure query string is utf-8
  * documentation fixes
* Sun Oct 29 2017 mvetter@suse.com
- Update to 1.0-alpha0:
  * mu4e: add mu4e-msg-changed-hook to mu4e-index-updated-hook globally
  * mu4e: Fix outdated docstring for `mu4e-headers-actions'
  * Add some improvements in attachment actions
  * mu4e: killing instead of interrupting update process
  * Use re-search-forward to find message signatures
  * mu4e: Add possibility to forward messages as attachments
  * mu: add 'tickle' command, for renaming messages
  * mu4e: allow for message body rewriting
  * mu4e: mu4e-message: allow for bodyless messages
  * mu4e: show inline text/plain as attachment
  * mu4e: don't require user-agent string
  * mu4e: Added new mu4e-split-view mode: single-window
  * mu: include signers in signature report
  * mu4e: display signers in signature header
  * bug fixes and documentation updates
* Thu Oct 26 2017 dimstar@opensuse.org
- Change gmime-devel BuildRequires to pkgconfig((gmime-2.6): do not
  care for actual package names, but for relevant symbols. In this
  specific case, gmime-devel was upgraded to version 3.0, with a
  2.6 compatibility package being present next to it.
* Tue Apr 11 2017 jengelh@inai.de
- Fix typographical issues with dots and apostrophes.
* Fri Apr  7 2017 mvetter@suse.com
- Use proper license (GPL-3.0+)
* Thu Apr  6 2017 mvetter@suse.com
- Add package mu4e (emacs+mu based email client)
- Change in BuildRequires:
  * Add emacs-nox >= 23, then mu4e gets automatically build
  * Add makeinfo, to handle info files
* Thu Mar  2 2017 mvetter@suse.com
- Initial package of version 0.9.18 for openSUSE
